==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/PolicyMappingLinks.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.HrefObjectSelfLink;
import com.okta.sdk.resource.model.PolicyMappingLinksAllOfApplication;
import com.okta.sdk.resource.model.PolicyMappingLinksAllOfPolicy;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * PolicyMappingLinks
 */
@JsonPropertyOrder({ PolicyMappingLinks.JSON_PROPERTY_SELF, PolicyMappingLinks.JSON_PROPERTY_APPLICATION,
        PolicyMappingLinks.JSON_PROPERTY_POLICY })
@JsonTypeName("PolicyMapping__links")
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class PolicyMappingLinks implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_SELF = "self";
    private HrefObjectSelfLink self;

    public static final String JSON_PROPERTY_APPLICATION = "application";
    private PolicyMappingLinksAllOfApplication application;

    public static final String JSON_PROPERTY_POLICY = "policy";
    private PolicyMappingLinksAllOfPolicy policy;

    public PolicyMappingLinks() {
    }

    public PolicyMappingLinks self(HrefObjectSelfLink self) {

        this.self = self;
        return this;
    }

    /**
     * Get self
     *
     * @return self
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObjectSelfLink getSelf() {
        return self;
    }

    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSelf(HrefObjectSelfLink self) {
        this.self = self;
    }

    public PolicyMappingLinks application(PolicyMappingLinksAllOfApplication application) {

        this.application = application;
        return this;
    }

    /**
     * Get application
     *
     * @return application
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_APPLICATION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PolicyMappingLinksAllOfApplication getApplication() {
        return application;
    }

    @JsonProperty(JSON_PROPERTY_APPLICATION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setApplication(PolicyMappingLinksAllOfApplication application) {
        this.application = application;
    }

    public PolicyMappingLinks policy(PolicyMappingLinksAllOfPolicy policy) {

        this.policy = policy;
        return this;
    }

    /**
     * Get policy
     *
     * @return policy
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_POLICY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PolicyMappingLinksAllOfPolicy getPolicy() {
        return policy;
    }

    @JsonProperty(JSON_PROPERTY_POLICY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPolicy(PolicyMappingLinksAllOfPolicy policy) {
        this.policy = policy;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        PolicyMappingLinks policyMappingLinks = (PolicyMappingLinks) o;
        return Objects.equals(this.self, policyMappingLinks.self)
                && Objects.equals(this.application, policyMappingLinks.application)
                && Objects.equals(this.policy, policyMappingLinks.policy);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(self, application, policy);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PolicyMappingLinks {\n");
        sb.append("    self: ").append(toIndentedString(self)).append("\n");
        sb.append("    application: ").append(toIndentedString(application)).append("\n");
        sb.append("    policy: ").append(toIndentedString(policy)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/PolicyMappingLinks.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.HrefObjectSelfLink;
import com.okta.sdk.resource.model.PolicyMappingLinksAllOfApplication;
import com.okta.sdk.resource.model.PolicyMappingLinksAllOfPolicy;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * PolicyMappingLinks
 */
@JsonPropertyOrder({ PolicyMappingLinks.JSON_PROPERTY_SELF, PolicyMappingLinks.JSON_PROPERTY_APPLICATION,
        PolicyMappingLinks.JSON_PROPERTY_POLICY })
@JsonTypeName("PolicyMapping__links")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class PolicyMappingLinks implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_SELF = "self";
    private HrefObjectSelfLink self;

    public static final String JSON_PROPERTY_APPLICATION = "application";
    private PolicyMappingLinksAllOfApplication application;

    public static final String JSON_PROPERTY_POLICY = "policy";
    private PolicyMappingLinksAllOfPolicy policy;

    public PolicyMappingLinks() {
    }

    public PolicyMappingLinks self(HrefObjectSelfLink self) {

        this.self = self;
        return this;
    }

    /**
     * Get self
     *
     * @return self
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObjectSelfLink getSelf() {
        return self;
    }

    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSelf(HrefObjectSelfLink self) {
        this.self = self;
    }

    public PolicyMappingLinks application(PolicyMappingLinksAllOfApplication application) {

        this.application = application;
        return this;
    }

    /**
     * Get application
     *
     * @return application
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_APPLICATION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PolicyMappingLinksAllOfApplication getApplication() {
        return application;
    }

    @JsonProperty(JSON_PROPERTY_APPLICATION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setApplication(PolicyMappingLinksAllOfApplication application) {
        this.application = application;
    }

    public PolicyMappingLinks policy(PolicyMappingLinksAllOfPolicy policy) {

        this.policy = policy;
        return this;
    }

    /**
     * Get policy
     *
     * @return policy
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_POLICY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PolicyMappingLinksAllOfPolicy getPolicy() {
        return policy;
    }

    @JsonProperty(JSON_PROPERTY_POLICY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPolicy(PolicyMappingLinksAllOfPolicy policy) {
        this.policy = policy;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        PolicyMappingLinks policyMappingLinks = (PolicyMappingLinks) o;
        return Objects.equals(this.self, policyMappingLinks.self)
                && Objects.equals(this.application, policyMappingLinks.application)
                && Objects.equals(this.policy, policyMappingLinks.policy);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(self, application, policy);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PolicyMappingLinks {\n");
        sb.append("    self: ").append(toIndentedString(self)).append("\n");
        sb.append("    application: ").append(toIndentedString(application)).append("\n");
        sb.append("    policy: ").append(toIndentedString(policy)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
